%define rel 1

Summary:	A program for synchronizing files over a network
Name:		rsync
Version: 	3.2.2
Release:	%mkrel %{?pre:0.%{pre}.%{rel}}%{?!pre:%{rel}}
Group:		Networking/File transfer
License:	GPLv3+
URL:		http://rsync.samba.org/
Source0:	http://rsync.samba.org/ftp/rsync/%{name}-%{version}%{?pre}.tar.gz
Source1:	http://rsync.samba.org/ftp/rsync/rsync.html
Source2:	http://rsync.samba.org/ftp/rsync/rsyncd.conf.html
Source4:	http://rsync.samba.org/ftp/rsync/%{name}-%{version}%{?pre}.tar.gz.asc
Source5:	http://rsync.samba.org/ftp/rsync/%{name}-patches-%{version}%{?pre}.tar.gz
Source6:	http://rsync.samba.org/ftp/rsync/%{name}-patches-%{version}%{?pre}.tar.gz.asc
Source12:	rsyncd.socket
Source13:	rsyncd.service
Source14:	rsyncd.conf
Source15:	rsyncd.sysconfig
Source16:	rsyncd@.service
BuildRequires:	xxhash-devel
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(popt)
BuildRequires:	libacl-devel
BuildRequires:	pkgconfig(zlib)
BuildRequires:	acl
Recommends:	openssh-clients

%define acl_patches 1

%{?_with_patches:%define acl_patches 1}
%{?_without_patches:%define acl_patches 0}

%description
Rsync uses a quick and reliable algorithm to very quickly bring
remote and host files into sync.  Rsync is fast because it just
sends the differences in the files over the network (instead of
sending the complete files). Rsync is often used as a very powerful
mirroring process or just as a more capable replacement for the
rcp command.  A technical report which describes the rsync algorithm
is included in this package.

Install rsync if you need a powerful mirroring program.
%if %acl_patches
This rpm has these patches applied from rsync tree:
  - acl: allow to mirror acl

Rebuild the source rpm with `--without patches' if you don't  want these patches
%endif

%prep
%if %acl_patches
%setup -q -D -b 5 -n %{name}-%{version}%{?pre}
%__patch -p1 -b -z .dir-del < patches/backup-dir-dels.diff
%__patch -p1 -b -z .acl < patches/acls.diff
%else
%setup -q -n %{name}-%{version}%{?pre}
%endif

%build
%__autoconf
%__autoheader
%serverbuild
rm -f config.h

%configure2_5x \
	--enable-acl-support \
	--without-included-zlib \
	--with-nobody-group=nogroup \
	--disable-simd

%make_build reconfigure

#make sure we use external zlib
rm -rf zlib

%make_build proto
%make_build

%check
%__make test

%install
%make_install

install -m644 %{SOURCE1} %{SOURCE2} .

install -D -m644 %{SOURCE12} %{buildroot}%{_unitdir}/rsyncd.socket
install -D -m644 %{SOURCE13} %{buildroot}%{_unitdir}/rsyncd.service
install -D -m644 %{SOURCE14} %{buildroot}%{_sysconfdir}/rsyncd.conf
install -D -m644 %{SOURCE15} %{buildroot}%{_sysconfdir}/sysconfig/rsyncd
install -D -m644 %{SOURCE16} %{buildroot}%{_unitdir}/rsyncd@.service

%files
%doc tech_report.tex README.md *html NEWS.md
%doc support/rrsync
%{_bindir}/rsync*
%{_mandir}/man1/rsync*.1*
%{_mandir}/man5/rsyncd.conf.5*
%config(noreplace) %{_sysconfdir}/rsyncd.conf
%config(noreplace) %{_sysconfdir}/sysconfig/rsyncd
%{_unitdir}/rsyncd.socket
%{_unitdir}/rsyncd.service
%{_unitdir}/rsyncd@.service


%changelog
* Sat Jul 25 2020 mokraemer <mokraemer> 3.2.2-1.mga7
+ Revision: 1608984
- backported for rsync fails on non existent directories (mga#25118)
- backport rsync

* Sun Jul 05 2020 daviddavid <daviddavid> 3.2.2-1.mga8
+ Revision: 1602453
- new version: 3.2.2

* Tue Jun 23 2020 daviddavid <daviddavid> 3.2.1-1.mga8
+ Revision: 1598643
- new version: 3.2.1

* Sat Jun 20 2020 kekepower <kekepower> 3.2.0-1.mga8
+ Revision: 1598142
- Update to version 3.2.0
- Remove Patches 0 and 7, fixed upstream differently

* Tue Feb 25 2020 mokraemer <mokraemer> 3.1.3-5.mga8
+ Revision: 1550442
- fix compilation issue
- remove internal zlib dependency, use system zlib

* Sat Feb 15 2020 umeabot <umeabot> 3.1.3-4.mga8
+ Revision: 1525988
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Mar 04 2019 mokraemer <mokraemer> 3.1.3-3.mga7
+ Revision: 1371433
- Fix vanished file bug, (mga#21395, smb#12569)

* Sun Sep 23 2018 umeabot <umeabot> 3.1.3-2.mga7
+ Revision: 1300860
- Mageia 7 Mass Rebuild

* Tue Apr 17 2018 kekepower <kekepower> 3.1.3-1.mga7
+ Revision: 1219720
- Update to version 3.1.3
- Remove CVE patches

* Sun Jan 28 2018 luigiwalser <luigiwalser> 3.1.2-4.mga7
+ Revision: 1197860
- add patch from ubuntu to fix CVE-2018-5764

* Tue Dec 19 2017 ns80 <ns80> 3.1.2-3.mga7
+ Revision: 1183446
- add patch from Debian for CVE-2017-16548 (mga#22216)

* Mon Dec 11 2017 ns80 <ns80> 3.1.2-2.mga7
+ Revision: 1182182
- add patches for CVE-2017-1743[34] (mga#22161)

* Tue Dec 22 2015 luigiwalser <luigiwalser> 3.1.2-1.mga6
+ Revision: 913289
- 3.1.2
- remove upstreamed CVE patches

* Thu Oct 15 2015 luigiwalser <luigiwalser> 3.1.1-6.mga6
+ Revision: 891901
- rediff upstream patch to fix same issue as CVE-2014-8242 from librsync

* Tue Feb 10 2015 luigiwalser <luigiwalser> 3.1.1-5.mga5
+ Revision: 814548
- add upstream patch to fix CVE-2014-9512
- fix use of setup macro so that patches actually get applied

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-4.mga5
+ Revision: 748531
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-3.mga5
+ Revision: 688728
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Jul 03 2014 tarakbumba <tarakbumba> 3.1.1-2.mga5
+ Revision: 642866
- Enable included zlib for backwards compability. Fixes mga#13669

* Mon Jun 23 2014 luigiwalser <luigiwalser> 3.1.1-1.mga5
+ Revision: 638860
- 3.1.1
- rediff patch 0
- remove upstreamed patch 1

* Tue Apr 15 2014 luigiwalser <luigiwalser> 3.1.0-7.mga5
+ Revision: 615166
- add upstream patch to fix CVE-2014-2855

* Mon Mar 03 2014 luigiwalser <luigiwalser> 3.1.0-6.mga5
+ Revision: 598910
- add rsync service template unit (mga#12925)

* Tue Dec 24 2013 dams <dams> 3.1.0-5.mga4
+ Revision: 560286
- suggests 'openssh-clients' as spotted on mga#11564

* Mon Oct 21 2013 umeabot <umeabot> 3.1.0-4.mga4
+ Revision: 538428
- Mageia 4 Mass Rebuild

* Mon Sep 30 2013 fwang <fwang> 3.1.0-3.mga4
+ Revision: 489596
- update man pages in html format

* Mon Sep 30 2013 fwang <fwang> 3.1.0-2.mga4
+ Revision: 489426
- update file list
- sync with fedora to use systemd settings for rsyncd
- use makeinstall_std
- cleanup spec

* Mon Sep 30 2013 fwang <fwang> 3.1.0-1.mga4
+ Revision: 489417
- new version 3.1.0

* Mon Jan 14 2013 umeabot <umeabot> 3.0.9-2.mga3
+ Revision: 380540
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 24 2011 fwang <fwang> 3.0.9-1.mga2
+ Revision: 147169
- new version 3.0.9

* Sat Apr 02 2011 ahmad <ahmad> 3.0.8-1.mga1
+ Revision: 79830
- update to 3.0.8
- don't disable lutime:
  o we have a recent enough kernel/glibc (and ideally Mageia doesn't officially
    support upgrading from 2008.x)
  o upstream now falls back to utime if lutime function is not around on the system
+ nanardon <nanardon>
- kill mandriva reference
- imported package rsync

